/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BranchProtectionAsResponse } from "../../definitions/BranchProtectionAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ProtectedBranchAsResponse } from "../../definitions/ProtectedBranchAsResponse";
import { ValidationErrorSimpleAsResponse } from "../../definitions/ValidationErrorSimpleAsResponse";
export interface GetBranchProtectionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
}
declare type GetBranchProtectionResponseOKType = BranchProtectionAsResponse;
export interface GetBranchProtectionResponseOK extends GetBranchProtectionResponseOKType {
}
declare type GetBranchProtectionResponseErrorType = BasicErrorAsResponse;
export interface GetBranchProtectionResponseError extends GetBranchProtectionResponseErrorType {
}
export interface UpdateBranchProtectionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
    body: {
        /**
         * Require status checks to pass before merging. Set to `null` to disable.
         */
        required_status_checks: {
            /**
             * Require branches to be up to date before merging.
             */
            strict: boolean;
            /**
      * **Deprecated**: The list of status checks to require in order to merge into this branch. If any of these checks have recently been set by a particular GitHub App, they will be required to come from that app in future for the branch to merge. Use `checks` instead of `contexts` for more fine-grained control.
      
      */
            contexts: Array<string>;
        } | null;
        /**
         * Enforce all configured restrictions for administrators. Set to `true` to enforce required status checks for repository administrators. Set to `null` to disable.
         */
        enforce_admins: boolean | null;
        /**
         * Require at least one approving review on a pull request, before merging. Set to `null` to disable.
         */
        required_pull_request_reviews: {
            /**
             * Specify which users and teams can dismiss pull request reviews. Pass an empty `dismissal_restrictions` object to disable. User and team `dismissal_restrictions` are only available for organization-owned repositories. Omit this parameter for personal repositories.
             */
            dismissal_restrictions?: {
                /**
                 * The list of user `login`s with dismissal access
                 */
                users?: Array<string>;
                /**
                 * The list of team `slug`s with dismissal access
                 */
                teams?: Array<string>;
            };
            /**
             * Set to `true` if you want to automatically dismiss approving reviews when someone pushes a new commit.
             */
            dismiss_stale_reviews?: boolean;
            /**
             * Blocks merging pull requests until [code owners](https://docs.github.com/articles/about-code-owners/) review them.
             */
            require_code_owner_reviews?: boolean;
            /**
             * Specify the number of reviewers required to approve pull requests. Use a number between 1 and 6 or 0 to not require reviewers.
             */
            required_approving_review_count?: number;
            /**
             * Allow specific users or teams to bypass pull request requirements.
             */
            bypass_pull_request_allowances?: {
                /**
                 * The list of user `login`s allowed to bypass pull request requirements.
                 */
                users?: Array<string>;
                /**
                 * The list of team `slug`s allowed to bypass pull request requirements.
                 */
                teams?: Array<string>;
            };
        } | null;
        /**
         * Restrict who can push to the protected branch. User, app, and team `restrictions` are only available for organization-owned repositories. Set to `null` to disable.
         */
        restrictions: {
            /**
             * The list of user `login`s with push access
             */
            users: Array<string>;
            /**
             * The list of team `slug`s with push access
             */
            teams: Array<string>;
            /**
             * The list of app `slug`s with push access
             */
            apps?: Array<string>;
        } | null;
        /**
         * Enforces a linear commit Git history, which prevents anyone from pushing merge commits to a branch. Set to `true` to enforce a linear commit history. Set to `false` to disable a linear commit Git history. Your repository must allow squash merging or rebase merging before you can enable a linear commit history. Default: `false`. For more information, see "[Requiring a linear commit history](https://docs.github.com/github/administering-a-repository/requiring-a-linear-commit-history)" in the GitHub Help documentation.
         */
        required_linear_history?: boolean;
        /**
         * Permits force pushes to the protected branch by anyone with write access to the repository. Set to `true` to allow force pushes. Set to `false` or `null` to block force pushes. Default: `false`. For more information, see "[Enabling force pushes to a protected branch](https://docs.github.com/en/github/administering-a-repository/enabling-force-pushes-to-a-protected-branch)" in the GitHub Help documentation."
         */
        allow_force_pushes?: boolean | null;
        /**
         * Allows deletion of the protected branch by anyone with write access to the repository. Set to `false` to prevent deletion of the protected branch. Default: `false`. For more information, see "[Enabling force pushes to a protected branch](https://docs.github.com/en/github/administering-a-repository/enabling-force-pushes-to-a-protected-branch)" in the GitHub Help documentation.
         */
        allow_deletions?: boolean;
        /**
         * Requires all conversations on code to be resolved before a pull request can be merged into a branch that matches this rule. Set to `false` to disable. Default: `false`.
         */
        required_conversation_resolution?: boolean;
    };
}
declare type UpdateBranchProtectionResponseOKType = ProtectedBranchAsResponse;
export interface UpdateBranchProtectionResponseOK extends UpdateBranchProtectionResponseOKType {
}
declare type UpdateBranchProtectionResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorSimpleAsResponse;
export interface UpdateBranchProtectionResponseError extends UpdateBranchProtectionResponseErrorType {
}
export interface DeleteBranchProtectionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
}
export declare type DeleteBranchProtectionResponseOK = undefined;
declare type DeleteBranchProtectionResponseErrorType = BasicErrorAsResponse;
export interface DeleteBranchProtectionResponseError extends DeleteBranchProtectionResponseErrorType {
}
export {};
//# sourceMappingURL=protection.d.ts.map