/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ProtectedBranchPullRequestReviewAsResponse } from "../../../../definitions/ProtectedBranchPullRequestReviewAsResponse";
import { ErrorStrategyOption } from "../../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ValidationErrorAsResponse } from "../../../../definitions/ValidationErrorAsResponse";
export interface GetBranchPullRequestReviewProtectionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
}
declare type GetBranchPullRequestReviewProtectionResponseOKType = ProtectedBranchPullRequestReviewAsResponse;
export interface GetBranchPullRequestReviewProtectionResponseOK extends GetBranchPullRequestReviewProtectionResponseOKType {
}
export declare type GetBranchPullRequestReviewProtectionResponseError = undefined;
export interface UpdateBranchPullRequestReviewProtectionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
    body: {
        /**
         * Specify which users, teams, and apps can dismiss pull request reviews. Pass an empty `dismissal_restrictions` object to disable. User and team `dismissal_restrictions` are only available for organization-owned repositories. Omit this parameter for personal repositories.
         */
        dismissal_restrictions?: {
            /**
             * The list of user `login`s with dismissal access
             */
            users?: Array<string>;
            /**
             * The list of team `slug`s with dismissal access
             */
            teams?: Array<string>;
            /**
             * The list of app `slug`s with dismissal access
             */
            apps?: Array<string>;
        };
        /**
         * Set to `true` if you want to automatically dismiss approving reviews when someone pushes a new commit.
         */
        dismiss_stale_reviews?: boolean;
        /**
         * Blocks merging pull requests until [code owners](https://docs.github.com/articles/about-code-owners/) have reviewed.
         */
        require_code_owner_reviews?: boolean;
        /**
         * Specifies the number of reviewers required to approve pull requests. Use a number between 1 and 6 or 0 to not require reviewers.
         */
        required_approving_review_count?: number;
        /**
         * Whether the most recent push must be approved by someone other than the person who pushed it. Default: `false`
         */
        require_last_push_approval?: boolean;
        /**
         * Allow specific users, teams, or apps to bypass pull request requirements.
         */
        bypass_pull_request_allowances?: {
            /**
             * The list of user `login`s allowed to bypass pull request requirements.
             */
            users?: Array<string>;
            /**
             * The list of team `slug`s allowed to bypass pull request requirements.
             */
            teams?: Array<string>;
            /**
             * The list of app `slug`s allowed to bypass pull request requirements.
             */
            apps?: Array<string>;
        };
    };
}
declare type UpdateBranchPullRequestReviewProtectionResponseOKType = ProtectedBranchPullRequestReviewAsResponse;
export interface UpdateBranchPullRequestReviewProtectionResponseOK extends UpdateBranchPullRequestReviewProtectionResponseOKType {
}
declare type UpdateBranchPullRequestReviewProtectionResponseErrorType = ValidationErrorAsResponse;
export interface UpdateBranchPullRequestReviewProtectionResponseError extends UpdateBranchPullRequestReviewProtectionResponseErrorType {
}
export {};
//# sourceMappingURL=review.d.ts.map