/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { StatusCheckPolicyAsResponse } from "../../../../definitions/StatusCheckPolicyAsResponse";
import { BasicErrorAsResponse } from "../../../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ValidationErrorAsResponse } from "../../../../definitions/ValidationErrorAsResponse";
export interface GetBranchStatusCheckProtectionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
}
declare type GetBranchStatusCheckProtectionResponseOKType = StatusCheckPolicyAsResponse;
export interface GetBranchStatusCheckProtectionResponseOK extends GetBranchStatusCheckProtectionResponseOKType {
}
declare type GetBranchStatusCheckProtectionResponseErrorType = BasicErrorAsResponse;
export interface GetBranchStatusCheckProtectionResponseError extends GetBranchStatusCheckProtectionResponseErrorType {
}
export interface UpdateBranchStatusCheckProtectionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
    body: {
        /**
         * Require branches to be up to date before merging.
         */
        strict?: boolean;
        /**
         * The list of status checks to require in order to merge into this branch.
         */
        checks?: Array<{
            /**
             * The name of the required check
             */
            context: string;
            /**
             * The ID of the GitHub App that must provide this check. Omit this field to automatically select the GitHub App that has recently provided this check, or any app if it was not set by a GitHub App. Pass -1 to explicitly allow any app to set the status.
             */
            app_id?: number;
        }>;
    };
}
declare type UpdateBranchStatusCheckProtectionResponseOKType = StatusCheckPolicyAsResponse;
export interface UpdateBranchStatusCheckProtectionResponseOK extends UpdateBranchStatusCheckProtectionResponseOKType {
}
declare type UpdateBranchStatusCheckProtectionResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface UpdateBranchStatusCheckProtectionResponseError extends UpdateBranchStatusCheckProtectionResponseErrorType {
}
export interface RemoveBranchStatusCheckProtectionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
}
export declare type RemoveBranchStatusCheckProtectionResponseOK = undefined;
export declare type RemoveBranchStatusCheckProtectionResponseError = undefined;
export interface GetBranchStatusCheckContextsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
}
declare type GetBranchStatusCheckContextsResponseOKType = Array<string>;
export interface GetBranchStatusCheckContextsResponseOK extends GetBranchStatusCheckContextsResponseOKType {
}
declare type GetBranchStatusCheckContextsResponseErrorType = BasicErrorAsResponse;
export interface GetBranchStatusCheckContextsResponseError extends GetBranchStatusCheckContextsResponseErrorType {
}
export interface AddBranchStatusCheckContextsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
    body: {
        /**
         * The name of the status checks
         */
        contexts: Array<string>;
    } | Array<string>;
}
declare type AddBranchStatusCheckContextsResponseOKType = Array<string>;
export interface AddBranchStatusCheckContextsResponseOK extends AddBranchStatusCheckContextsResponseOKType {
}
declare type AddBranchStatusCheckContextsResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface AddBranchStatusCheckContextsResponseError extends AddBranchStatusCheckContextsResponseErrorType {
}
export interface SetBranchStatusCheckContextsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
    body: {
        /**
         * The name of the status checks
         */
        contexts: Array<string>;
    } | Array<string>;
}
declare type SetBranchStatusCheckContextsResponseOKType = Array<string>;
export interface SetBranchStatusCheckContextsResponseOK extends SetBranchStatusCheckContextsResponseOKType {
}
declare type SetBranchStatusCheckContextsResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface SetBranchStatusCheckContextsResponseError extends SetBranchStatusCheckContextsResponseErrorType {
}
export interface RemoveBranchStatusCheckContextsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the branch. Cannot contain wildcard characters. To use wildcard characters in branch names, use [the GraphQL API](https://docs.github.com/graphql).
     */
    branch: string;
    body: {
        /**
         * The name of the status checks
         */
        contexts: Array<string>;
    } | Array<string>;
}
declare type RemoveBranchStatusCheckContextsResponseOKType = Array<string>;
export interface RemoveBranchStatusCheckContextsResponseOK extends RemoveBranchStatusCheckContextsResponseOKType {
}
declare type RemoveBranchStatusCheckContextsResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface RemoveBranchStatusCheckContextsResponseError extends RemoveBranchStatusCheckContextsResponseErrorType {
}
export {};
//# sourceMappingURL=check.d.ts.map