/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CommitCommentAsResponse } from "../../definitions/CommitCommentAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
export interface GetCommitCommentsForRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetCommitCommentsForRepositoryResponseOKType = Array<CommitCommentAsResponse>;
export interface GetCommitCommentsForRepositoryResponseOK extends GetCommitCommentsForRepositoryResponseOKType {
}
export declare type GetCommitCommentsForRepositoryResponseError = undefined;
export interface GetCommitCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
}
declare type GetCommitCommentResponseOKType = CommitCommentAsResponse;
export interface GetCommitCommentResponseOK extends GetCommitCommentResponseOKType {
}
declare type GetCommitCommentResponseErrorType = BasicErrorAsResponse;
export interface GetCommitCommentResponseError extends GetCommitCommentResponseErrorType {
}
export interface UpdateCommitCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
    body: {
        /**
         * The contents of the comment
         */
        body: string;
    };
}
declare type UpdateCommitCommentResponseOKType = CommitCommentAsResponse;
export interface UpdateCommitCommentResponseOK extends UpdateCommitCommentResponseOKType {
}
declare type UpdateCommitCommentResponseErrorType = BasicErrorAsResponse;
export interface UpdateCommitCommentResponseError extends UpdateCommitCommentResponseErrorType {
}
export interface DeleteCommitCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
}
export declare type DeleteCommitCommentResponseOK = undefined;
declare type DeleteCommitCommentResponseErrorType = BasicErrorAsResponse;
export interface DeleteCommitCommentResponseError extends DeleteCommitCommentResponseErrorType {
}
export interface GetCommitCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The SHA of the commit.
     */
    commit_sha: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetCommitCommentsResponseOKType = Array<CommitCommentAsResponse>;
export interface GetCommitCommentsResponseOK extends GetCommitCommentsResponseOKType {
}
export declare type GetCommitCommentsResponseError = undefined;
export interface CreateCommitCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The SHA of the commit.
     */
    commit_sha: string;
    body: {
        /**
         * The contents of the comment.
         */
        body: string;
        /**
         * Relative path of the file to comment on.
         */
        path?: string;
        /**
         * Line index in the diff to comment on.
         */
        position?: number;
    };
}
declare type CreateCommitCommentResponseOKType = CommitCommentAsResponse;
export interface CreateCommitCommentResponseOK extends CreateCommitCommentResponseOKType {
}
declare type CreateCommitCommentResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateCommitCommentResponseError extends CreateCommitCommentResponseErrorType {
}
export {};
//# sourceMappingURL=comment.d.ts.map