/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CombinedCommitStatusAsResponse } from "../../definitions/CombinedCommitStatusAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { StatusAsResponse } from "../../definitions/StatusAsResponse";
export interface GetCombinedCommitStatusForReferenceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * ref parameter
     */
    ref: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetCombinedCommitStatusForReferenceResponseOKType = CombinedCommitStatusAsResponse;
export interface GetCombinedCommitStatusForReferenceResponseOK extends GetCombinedCommitStatusForReferenceResponseOKType {
}
declare type GetCombinedCommitStatusForReferenceResponseErrorType = BasicErrorAsResponse;
export interface GetCombinedCommitStatusForReferenceResponseError extends GetCombinedCommitStatusForReferenceResponseErrorType {
}
export interface GetCommitStatusesForReferenceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * ref parameter
     */
    ref: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetCommitStatusesForReferenceResponseOKType = Array<StatusAsResponse>;
export interface GetCommitStatusesForReferenceResponseOK extends GetCommitStatusesForReferenceResponseOKType {
}
declare type GetCommitStatusesForReferenceResponseErrorType = BasicErrorAsResponse;
export interface GetCommitStatusesForReferenceResponseError extends GetCommitStatusesForReferenceResponseErrorType {
}
export interface CreateCommitStatusRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    sha: string;
    body: {
        /**
         * The state of the status.
         */
        state: "error" | "failure" | "pending" | "success";
        /**
    * The target URL to associate with this status. This URL will be linked from the GitHub UI to allow users to easily see the source of the status.
    For example, if your continuous integration system is posting build status, you would want to provide the deep link for the build output for this specific SHA:
    `http://ci.example.com/user/repo/build/sha`
    */
        target_url?: string | null;
        /**
         * A short description of the status.
         */
        description?: string | null;
        /**
         * A string label to differentiate this status from the status of other systems. This field is case-insensitive.
         */
        context?: string;
    };
}
declare type CreateCommitStatusResponseOKType = StatusAsResponse;
export interface CreateCommitStatusResponseOK extends CreateCommitStatusResponseOKType {
}
export declare type CreateCommitStatusResponseError = undefined;
export {};
//# sourceMappingURL=status.d.ts.map