/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { EnvironmentsAsResponse } from "../../definitions/EnvironmentsAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { EnvironmentAsResponse } from "../../definitions/EnvironmentAsResponse";
import { WaitTimer } from "../../definitions/WaitTimer";
import { DeploymentReviewerType } from "../../definitions/DeploymentReviewerType";
import { DeploymentBranchPolicySettings } from "../../definitions/DeploymentBranchPolicySettings";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
export interface GetDeploymentEnvironmentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
declare type GetDeploymentEnvironmentsResponseOKType = EnvironmentsAsResponse;
export interface GetDeploymentEnvironmentsResponseOK extends GetDeploymentEnvironmentsResponseOKType {
}
export declare type GetDeploymentEnvironmentsResponseError = undefined;
export interface GetDeploymentEnvironmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the environment.
     */
    environment_name: string;
}
declare type GetDeploymentEnvironmentResponseOKType = EnvironmentAsResponse;
export interface GetDeploymentEnvironmentResponseOK extends GetDeploymentEnvironmentResponseOKType {
}
export declare type GetDeploymentEnvironmentResponseError = undefined;
export interface CreateOrUpdateDeploymentEnvironmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the environment.
     */
    environment_name: string;
    body: {
        wait_timer?: WaitTimer;
        /**
         * The people or teams that may review jobs that reference the environment. You can list up to six users or teams as reviewers. The reviewers must have at least read access to the repository. Only one of the required reviewers needs to approve the job for it to proceed.
         */
        reviewers?: Array<{
            type?: DeploymentReviewerType;
            /**
             * The id of the user or team who can review the deployment
             */
            id?: number;
        }> | null;
        deployment_branch_policy?: DeploymentBranchPolicySettings;
    } | null;
}
declare type CreateOrUpdateDeploymentEnvironmentResponseOKType = EnvironmentAsResponse;
export interface CreateOrUpdateDeploymentEnvironmentResponseOK extends CreateOrUpdateDeploymentEnvironmentResponseOKType {
}
declare type CreateOrUpdateDeploymentEnvironmentResponseErrorType = BasicErrorAsResponse;
export interface CreateOrUpdateDeploymentEnvironmentResponseError extends CreateOrUpdateDeploymentEnvironmentResponseErrorType {
}
export interface DeleteDeploymentEnvironmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the environment.
     */
    environment_name: string;
}
export declare type DeleteDeploymentEnvironmentResponseOK = undefined;
export declare type DeleteDeploymentEnvironmentResponseError = undefined;
export {};
//# sourceMappingURL=environment.d.ts.map