/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DeployKeyAsResponse } from "../../definitions/DeployKeyAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
export interface GetDeploymentKeysRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetDeploymentKeysResponseOKType = Array<DeployKeyAsResponse>;
export interface GetDeploymentKeysResponseOK extends GetDeploymentKeysResponseOKType {
}
export declare type GetDeploymentKeysResponseError = undefined;
export interface CreateDeploymentKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * A name for the key.
         */
        title?: string;
        /**
         * The contents of the key.
         */
        key: string;
        /**
    * If `true`, the key will only be able to read repository contents. Otherwise, the key will be able to read and write.
      
    Deploy keys with write access can perform the same actions as an organization member with admin access, or a collaborator on a personal repository. For more information, see "[Repository permission levels for an organization](https://docs.github.com/articles/repository-permission-levels-for-an-organization/)" and "[Permission levels for a user account repository](https://docs.github.com/articles/permission-levels-for-a-user-account-repository/)."
    */
        read_only?: boolean;
    };
}
declare type CreateDeploymentKeyResponseOKType = DeployKeyAsResponse;
export interface CreateDeploymentKeyResponseOK extends CreateDeploymentKeyResponseOKType {
}
declare type CreateDeploymentKeyResponseErrorType = ValidationErrorAsResponse;
export interface CreateDeploymentKeyResponseError extends CreateDeploymentKeyResponseErrorType {
}
export interface GetDeploymentKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the key.
     */
    key_id: number;
}
declare type GetDeploymentKeyResponseOKType = DeployKeyAsResponse;
export interface GetDeploymentKeyResponseOK extends GetDeploymentKeyResponseOKType {
}
declare type GetDeploymentKeyResponseErrorType = BasicErrorAsResponse;
export interface GetDeploymentKeyResponseError extends GetDeploymentKeyResponseErrorType {
}
export interface DeleteDeploymentKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the key.
     */
    key_id: number;
}
export declare type DeleteDeploymentKeyResponseOK = undefined;
export declare type DeleteDeploymentKeyResponseError = undefined;
export {};
//# sourceMappingURL=key.d.ts.map