/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DeploymentStatusAsResponse } from "../../definitions/DeploymentStatusAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
export interface GetDeploymentStatusesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * deployment_id parameter
     */
    deployment_id: number;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetDeploymentStatusesResponseOKType = Array<DeploymentStatusAsResponse>;
export interface GetDeploymentStatusesResponseOK extends GetDeploymentStatusesResponseOKType {
}
declare type GetDeploymentStatusesResponseErrorType = BasicErrorAsResponse;
export interface GetDeploymentStatusesResponseError extends GetDeploymentStatusesResponseErrorType {
}
export interface CreateDeploymentStatusRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * deployment_id parameter
     */
    deployment_id: number;
    body: {
        /**
         * The state of the status. When you set a transient deployment to `inactive`, the deployment will be shown as `destroyed` in GitHub.
         */
        state: "error" | "failure" | "inactive" | "in_progress" | "queued" | "pending" | "success";
        /**
         * The target URL to associate with this status. This URL should contain output to keep the user updated while the task is running or serve as historical information for what happened in the deployment. **Note:** It's recommended to use the `log_url` parameter, which replaces `target_url`.
         */
        target_url?: string;
        /**
         * The full URL of the deployment's output. This parameter replaces `target_url`. We will continue to accept `target_url` to support legacy uses, but we recommend replacing `target_url` with `log_url`. Setting `log_url` will automatically set `target_url` to the same value. Default: `""`
         */
        log_url?: string;
        /**
         * A short description of the status. The maximum description length is 140 characters.
         */
        description?: string;
        /**
         * Name for the target deployment environment, which can be changed when setting a deploy status. For example, `production`, `staging`, or `qa`.
         */
        environment?: "production" | "staging" | "qa";
        /**
         * Sets the URL for accessing your environment. Default: `""`
         */
        environment_url?: string;
        /**
         * Adds a new `inactive` status to all prior non-transient, non-production environment deployments with the same repository and `environment` name as the created status's deployment. An `inactive` status is only added to deployments that had a `success` state. Default: `true`
         */
        auto_inactive?: boolean;
    };
}
declare type CreateDeploymentStatusResponseOKType = DeploymentStatusAsResponse;
export interface CreateDeploymentStatusResponseOK extends CreateDeploymentStatusResponseOKType {
}
declare type CreateDeploymentStatusResponseErrorType = ValidationErrorAsResponse;
export interface CreateDeploymentStatusResponseError extends CreateDeploymentStatusResponseErrorType {
}
export interface GetDeploymentStatusRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * deployment_id parameter
     */
    deployment_id: number;
    status_id: number;
}
declare type GetDeploymentStatusResponseOKType = DeploymentStatusAsResponse;
export interface GetDeploymentStatusResponseOK extends GetDeploymentStatusResponseOKType {
}
declare type GetDeploymentStatusResponseErrorType = BasicErrorAsResponse;
export interface GetDeploymentStatusResponseError extends GetDeploymentStatusResponseErrorType {
}
export {};
//# sourceMappingURL=status.d.ts.map