/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ShortBlobAsResponse } from "../../definitions/ShortBlobAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BlobAsResponse } from "../../definitions/BlobAsResponse";
export interface CreateGitBlobRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * The new blob's content.
         */
        content: string;
        /**
         * The encoding used for `content`. Currently, `"utf-8"` and `"base64"` are supported.
         */
        encoding?: "utf-8" | "base64";
    };
}
declare type CreateGitBlobResponseOKType = ShortBlobAsResponse;
export interface CreateGitBlobResponseOK extends CreateGitBlobResponseOKType {
}
declare type CreateGitBlobResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateGitBlobResponseError extends CreateGitBlobResponseErrorType {
}
export interface GetGitBlobRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    file_sha: string;
}
declare type GetGitBlobResponseOKType = BlobAsResponse;
export interface GetGitBlobResponseOK extends GetGitBlobResponseOKType {
}
declare type GetGitBlobResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface GetGitBlobResponseError extends GetGitBlobResponseErrorType {
}
export {};
//# sourceMappingURL=blob.d.ts.map