/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GitRefAsResponse } from "../../definitions/GitRefAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
export interface GetGitMatchingReferencesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * ref parameter
     */
    ref: string;
}
declare type GetGitMatchingReferencesResponseOKType = Array<GitRefAsResponse>;
export interface GetGitMatchingReferencesResponseOK extends GetGitMatchingReferencesResponseOKType {
}
export declare type GetGitMatchingReferencesResponseError = undefined;
export interface GetGitReferenceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * ref parameter
     */
    ref: string;
}
declare type GetGitReferenceResponseOKType = GitRefAsResponse;
export interface GetGitReferenceResponseOK extends GetGitReferenceResponseOKType {
}
declare type GetGitReferenceResponseErrorType = BasicErrorAsResponse;
export interface GetGitReferenceResponseError extends GetGitReferenceResponseErrorType {
}
export interface CreateGitReferenceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * The name of the fully qualified reference (ie: `refs/heads/master`). If it doesn't start with 'refs' and have at least two slashes, it will be rejected.
         */
        ref: string;
        /**
         * The SHA1 value for this reference.
         */
        sha: string;
        key?: string;
    };
}
declare type CreateGitReferenceResponseOKType = GitRefAsResponse;
export interface CreateGitReferenceResponseOK extends CreateGitReferenceResponseOKType {
}
declare type CreateGitReferenceResponseErrorType = ValidationErrorAsResponse;
export interface CreateGitReferenceResponseError extends CreateGitReferenceResponseErrorType {
}
export interface UpdateGitReferenceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the fully qualified reference to update. For example, `refs/heads/master`. If the value doesn't start with `refs` and have at least two slashes, it will be rejected.
     */
    ref: string;
    body: {
        /**
         * The SHA1 value to set this reference to
         */
        sha: string;
        /**
         * Indicates whether to force the update or to make sure the update is a fast-forward update. Leaving this out or setting it to `false` will make sure you're not overwriting work.
         */
        force?: boolean;
    };
}
declare type UpdateGitReferenceResponseOKType = GitRefAsResponse;
export interface UpdateGitReferenceResponseOK extends UpdateGitReferenceResponseOKType {
}
declare type UpdateGitReferenceResponseErrorType = ValidationErrorAsResponse;
export interface UpdateGitReferenceResponseError extends UpdateGitReferenceResponseErrorType {
}
export interface DeleteGitReferenceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * ref parameter
     */
    ref: string;
}
export declare type DeleteGitReferenceResponseOK = undefined;
declare type DeleteGitReferenceResponseErrorType = ValidationErrorAsResponse;
export interface DeleteGitReferenceResponseError extends DeleteGitReferenceResponseErrorType {
}
export {};
//# sourceMappingURL=reference.d.ts.map