/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GitTagAsResponse } from "../../definitions/GitTagAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
export interface CreateGitTagRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * The tag's name. This is typically a version (e.g., "v0.0.1").
         */
        tag: string;
        /**
         * The tag message.
         */
        message: string;
        /**
         * The SHA of the git object this is tagging.
         */
        object: string;
        /**
         * The type of the object we're tagging. Normally this is a `commit` but it can also be a `tree` or a `blob`.
         */
        type: "commit" | "tree" | "blob";
        /**
         * An object with information about the individual creating the tag.
         */
        tagger?: {
            /**
             * The name of the author of the tag
             */
            name: string;
            /**
             * The email of the author of the tag
             */
            email: string;
            /**
             * When this object was tagged. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
             */
            date?: string;
        };
    };
}
declare type CreateGitTagResponseOKType = GitTagAsResponse;
export interface CreateGitTagResponseOK extends CreateGitTagResponseOKType {
}
declare type CreateGitTagResponseErrorType = ValidationErrorAsResponse;
export interface CreateGitTagResponseError extends CreateGitTagResponseErrorType {
}
export interface GetGitTagRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    tag_sha: string;
}
declare type GetGitTagResponseOKType = GitTagAsResponse;
export interface GetGitTagResponseOK extends GetGitTagResponseOKType {
}
declare type GetGitTagResponseErrorType = BasicErrorAsResponse;
export interface GetGitTagResponseError extends GetGitTagResponseErrorType {
}
export {};
//# sourceMappingURL=tag.d.ts.map