/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { SimpleUserAsResponse } from "../../definitions/SimpleUserAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { IssueAsResponse } from "../../definitions/IssueAsResponse";
export interface GetIssueAssigneesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetIssueAssigneesResponseOKType = Array<SimpleUserAsResponse>;
export interface GetIssueAssigneesResponseOK extends GetIssueAssigneesResponseOKType {
}
declare type GetIssueAssigneesResponseErrorType = BasicErrorAsResponse;
export interface GetIssueAssigneesResponseError extends GetIssueAssigneesResponseErrorType {
}
export interface CanUserBeAssigneToIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    assignee: string;
}
export declare type CanUserBeAssigneToIssueResponseOK = undefined;
declare type CanUserBeAssigneToIssueResponseErrorType = BasicErrorAsResponse;
export interface CanUserBeAssigneToIssueResponseError extends CanUserBeAssigneToIssueResponseErrorType {
}
export interface AddIssueAssigneesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the issue.
     */
    issue_number: number;
    body: {
        /**
         * Usernames of people to assign this issue to. _NOTE: Only users with push access can add assignees to an issue. Assignees are silently ignored otherwise._
         */
        assignees?: Array<string>;
    };
}
declare type AddIssueAssigneesResponseOKType = IssueAsResponse;
export interface AddIssueAssigneesResponseOK extends AddIssueAssigneesResponseOKType {
}
export declare type AddIssueAssigneesResponseError = undefined;
export interface RemoveIssueAssigneesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the issue.
     */
    issue_number: number;
    body: {
        /**
         * Usernames of assignees to remove from an issue. _NOTE: Only users with push access can remove assignees from an issue. Assignees are silently ignored otherwise._
         */
        assignees?: Array<string>;
    };
}
declare type RemoveIssueAssigneesResponseOKType = IssueAsResponse;
export interface RemoveIssueAssigneesResponseOK extends RemoveIssueAssigneesResponseOKType {
}
export declare type RemoveIssueAssigneesResponseError = undefined;
export {};
//# sourceMappingURL=assignee.d.ts.map