/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { IssueCommentAsResponse } from "../../definitions/IssueCommentAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetIssueCommentsForRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
     */
    sort?: "created" | "updated";
    /**
     * Either `asc` or `desc`. Ignored without the `sort` parameter.
     */
    direction?: "asc" | "desc";
    /**
     * Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
     */
    since?: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetIssueCommentsForRepositoryResponseOKType = Array<IssueCommentAsResponse>;
export interface GetIssueCommentsForRepositoryResponseOK extends GetIssueCommentsForRepositoryResponseOKType {
}
declare type GetIssueCommentsForRepositoryResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface GetIssueCommentsForRepositoryResponseError extends GetIssueCommentsForRepositoryResponseErrorType {
}
export interface GetIssueCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
}
declare type GetIssueCommentResponseOKType = IssueCommentAsResponse;
export interface GetIssueCommentResponseOK extends GetIssueCommentResponseOKType {
}
declare type GetIssueCommentResponseErrorType = BasicErrorAsResponse;
export interface GetIssueCommentResponseError extends GetIssueCommentResponseErrorType {
}
export interface UpdateIssueCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
    body: {
        /**
         * The contents of the comment.
         */
        body: string;
    };
}
declare type UpdateIssueCommentResponseOKType = IssueCommentAsResponse;
export interface UpdateIssueCommentResponseOK extends UpdateIssueCommentResponseOKType {
}
declare type UpdateIssueCommentResponseErrorType = ValidationErrorAsResponse;
export interface UpdateIssueCommentResponseError extends UpdateIssueCommentResponseErrorType {
}
export interface DeleteIssueCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
}
export declare type DeleteIssueCommentResponseOK = undefined;
export declare type DeleteIssueCommentResponseError = undefined;
export interface GetIssueCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the issue.
     */
    issue_number: number;
    /**
     * Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
     */
    since?: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetIssueCommentsResponseOKType = Array<IssueCommentAsResponse>;
export interface GetIssueCommentsResponseOK extends GetIssueCommentsResponseOKType {
}
declare type GetIssueCommentsResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse;
export interface GetIssueCommentsResponseError extends GetIssueCommentsResponseErrorType {
}
export interface CreateIssueCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the issue.
     */
    issue_number: number;
    body: {
        /**
         * The contents of the comment.
         */
        body: string;
    };
}
declare type CreateIssueCommentResponseOKType = IssueCommentAsResponse;
export interface CreateIssueCommentResponseOK extends CreateIssueCommentResponseOKType {
}
declare type CreateIssueCommentResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateIssueCommentResponseError extends CreateIssueCommentResponseErrorType {
}
export {};
//# sourceMappingURL=comment.d.ts.map