/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { LabelAsResponse } from "../../definitions/LabelAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
export interface GetIssueLabelsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the issue.
     */
    issue_number: number;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetIssueLabelsResponseOKType = Array<LabelAsResponse>;
export interface GetIssueLabelsResponseOK extends GetIssueLabelsResponseOKType {
}
declare type GetIssueLabelsResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse;
export interface GetIssueLabelsResponseError extends GetIssueLabelsResponseErrorType {
}
export interface AddLabelsToIssueRequest extends HeadersOption, ErrorStrategyOption {
    owner: string;
    repo: string;
    /**
     * issue_number parameter
     */
    issue_number: number;
    body: {
        /**
         * The names of the labels to add to the issue's existing labels.
         */
        labels?: Array<string>;
    };
}
export interface AddLabelsToIssueResponseOK extends Array<LabelAsResponse> {
}
declare type AddLabelsToIssueResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface AddLabelsToIssueResponseError extends AddLabelsToIssueResponseErrorType {
}
export interface SetLabelsToIssueRequest extends HeadersOption, ErrorStrategyOption {
    owner: string;
    repo: string;
    /**
     * issue_number parameter
     */
    issue_number: number;
    body: {
        /**
         * The names of the labels to set for the issue. The labels you set replace any existing labels. You can pass an empty array to remove all labels.
         */
        labels?: Array<string>;
    };
}
export interface SetLabelsToIssueResponseOK extends Array<LabelAsResponse> {
}
declare type SetLabelsToIssueResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface SetLabelsToIssueResponseError extends SetLabelsToIssueResponseErrorType {
}
export interface RemoveLabelsFromIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the issue.
     */
    issue_number: number;
}
export declare type RemoveLabelsFromIssueResponseOK = undefined;
declare type RemoveLabelsFromIssueResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse;
export interface RemoveLabelsFromIssueResponseError extends RemoveLabelsFromIssueResponseErrorType {
}
export interface RemoveLabelFromIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the issue.
     */
    issue_number: number;
    name: string;
}
declare type RemoveLabelFromIssueResponseOKType = Array<LabelAsResponse>;
export interface RemoveLabelFromIssueResponseOK extends RemoveLabelFromIssueResponseOKType {
}
declare type RemoveLabelFromIssueResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse;
export interface RemoveLabelFromIssueResponseError extends RemoveLabelFromIssueResponseErrorType {
}
export interface GetIssueLabelsForRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetIssueLabelsForRepositoryResponseOKType = Array<LabelAsResponse>;
export interface GetIssueLabelsForRepositoryResponseOK extends GetIssueLabelsForRepositoryResponseOKType {
}
declare type GetIssueLabelsForRepositoryResponseErrorType = BasicErrorAsResponse;
export interface GetIssueLabelsForRepositoryResponseError extends GetIssueLabelsForRepositoryResponseErrorType {
}
export interface CreateIssueLabelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * The name of the label. Emoji can be added to label names, using either native emoji or colon-style markup. For example, typing `:strawberry:` will render the emoji ![:strawberry:](https://github.githubassets.com/images/icons/emoji/unicode/1f353.png ":strawberry:"). For a full list of available emoji and codes, see "[Emoji cheat sheet](https://github.com/ikatyang/emoji-cheat-sheet)."
         */
        name: string;
        /**
         * The [hexadecimal color code](http://www.color-hex.com/) for the label, without the leading `#`.
         */
        color?: string;
        /**
         * A short description of the label. Must be 100 characters or fewer.
         */
        description?: string;
    };
}
declare type CreateIssueLabelResponseOKType = LabelAsResponse;
export interface CreateIssueLabelResponseOK extends CreateIssueLabelResponseOKType {
}
declare type CreateIssueLabelResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateIssueLabelResponseError extends CreateIssueLabelResponseErrorType {
}
export interface GetIssueLabelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    name: string;
}
declare type GetIssueLabelResponseOKType = LabelAsResponse;
export interface GetIssueLabelResponseOK extends GetIssueLabelResponseOKType {
}
declare type GetIssueLabelResponseErrorType = BasicErrorAsResponse;
export interface GetIssueLabelResponseError extends GetIssueLabelResponseErrorType {
}
export interface UpdateIssueLabelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    name: string;
    body: {
        /**
         * The new name of the label. Emoji can be added to label names, using either native emoji or colon-style markup. For example, typing `:strawberry:` will render the emoji ![:strawberry:](https://github.githubassets.com/images/icons/emoji/unicode/1f353.png ":strawberry:"). For a full list of available emoji and codes, see "[Emoji cheat sheet](https://github.com/ikatyang/emoji-cheat-sheet)."
         */
        new_name?: string;
        /**
         * The [hexadecimal color code](http://www.color-hex.com/) for the label, without the leading `#`.
         */
        color?: string;
        /**
         * A short description of the label. Must be 100 characters or fewer.
         */
        description?: string;
    };
}
declare type UpdateIssueLabelResponseOKType = LabelAsResponse;
export interface UpdateIssueLabelResponseOK extends UpdateIssueLabelResponseOKType {
}
export declare type UpdateIssueLabelResponseError = undefined;
export interface DeleteIssueLabelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    name: string;
}
export declare type DeleteIssueLabelResponseOK = undefined;
export declare type DeleteIssueLabelResponseError = undefined;
export interface GetLabelsForIssuesInMilestoneRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the milestone.
     */
    milestone_number: number;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetLabelsForIssuesInMilestoneResponseOKType = Array<LabelAsResponse>;
export interface GetLabelsForIssuesInMilestoneResponseOK extends GetLabelsForIssuesInMilestoneResponseOKType {
}
export declare type GetLabelsForIssuesInMilestoneResponseError = undefined;
export {};
//# sourceMappingURL=label.d.ts.map