/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { MilestoneAsResponse } from "../../definitions/MilestoneAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
export interface GetIssueMilestonesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The state of the milestone. Either `open`, `closed`, or `all`.
     */
    state?: "open" | "closed" | "all";
    /**
     * What to sort results by. Either `due_on` or `completeness`.
     */
    sort?: "due_on" | "completeness";
    /**
     * The direction of the sort. Either `asc` or `desc`.
     */
    direction?: "asc" | "desc";
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetIssueMilestonesResponseOKType = Array<MilestoneAsResponse>;
export interface GetIssueMilestonesResponseOK extends GetIssueMilestonesResponseOKType {
}
declare type GetIssueMilestonesResponseErrorType = BasicErrorAsResponse;
export interface GetIssueMilestonesResponseError extends GetIssueMilestonesResponseErrorType {
}
export interface CreateIssueMilestoneRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * The title of the milestone.
         */
        title: string;
        /**
         * The state of the milestone. Either `open` or `closed`.
         */
        state?: "open" | "closed";
        /**
         * A description of the milestone.
         */
        description?: string;
        /**
         * The milestone due date. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
         */
        due_on?: string;
    };
}
declare type CreateIssueMilestoneResponseOKType = MilestoneAsResponse;
export interface CreateIssueMilestoneResponseOK extends CreateIssueMilestoneResponseOKType {
}
declare type CreateIssueMilestoneResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateIssueMilestoneResponseError extends CreateIssueMilestoneResponseErrorType {
}
export interface GetIssueMilestoneRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the milestone.
     */
    milestone_number: number;
}
declare type GetIssueMilestoneResponseOKType = MilestoneAsResponse;
export interface GetIssueMilestoneResponseOK extends GetIssueMilestoneResponseOKType {
}
declare type GetIssueMilestoneResponseErrorType = BasicErrorAsResponse;
export interface GetIssueMilestoneResponseError extends GetIssueMilestoneResponseErrorType {
}
export interface UpdateIssueMilestoneRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the milestone.
     */
    milestone_number: number;
    body: {
        /**
         * The title of the milestone.
         */
        title?: string;
        /**
         * The state of the milestone. Either `open` or `closed`.
         */
        state?: "open" | "closed";
        /**
         * A description of the milestone.
         */
        description?: string;
        /**
         * The milestone due date. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
         */
        due_on?: string;
    };
}
declare type UpdateIssueMilestoneResponseOKType = MilestoneAsResponse;
export interface UpdateIssueMilestoneResponseOK extends UpdateIssueMilestoneResponseOKType {
}
export declare type UpdateIssueMilestoneResponseError = undefined;
export interface DeleteIssueMilestoneRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the milestone.
     */
    milestone_number: number;
}
export declare type DeleteIssueMilestoneResponseOK = undefined;
declare type DeleteIssueMilestoneResponseErrorType = BasicErrorAsResponse;
export interface DeleteIssueMilestoneResponseError extends DeleteIssueMilestoneResponseErrorType {
}
export {};
//# sourceMappingURL=milestone.d.ts.map