/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { SimpleUserAsResponse } from "../../definitions/SimpleUserAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { OrgMembershipAsResponse } from "../../definitions/OrgMembershipAsResponse";
export interface GetOrganizationMembersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    /**
     * Filter members returned in the list. `2fa_disabled` means that only members without [two-factor authentication](https://github.com/blog/1614-two-factor-authentication) enabled will be returned. This options is only available for organization owners.
     */
    filter?: "2fa_disabled" | "all";
    /**
     * Filter members returned by their role.
     */
    role?: "all" | "admin" | "member";
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetOrganizationMembersResponseOKType = Array<SimpleUserAsResponse>;
export interface GetOrganizationMembersResponseOK extends GetOrganizationMembersResponseOKType {
}
declare type GetOrganizationMembersResponseErrorType = ValidationErrorAsResponse;
export interface GetOrganizationMembersResponseError extends GetOrganizationMembersResponseErrorType {
}
export interface CheckOrganizationMembershipForUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
}
export declare type CheckOrganizationMembershipForUserResponseOK = undefined;
export declare type CheckOrganizationMembershipForUserResponseError = undefined;
export interface RemoveOrganizationMemberRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
}
export declare type RemoveOrganizationMemberResponseOK = undefined;
declare type RemoveOrganizationMemberResponseErrorType = BasicErrorAsResponse;
export interface RemoveOrganizationMemberResponseError extends RemoveOrganizationMemberResponseErrorType {
}
export interface GetOrganizationMembershipForUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
}
declare type GetOrganizationMembershipForUserResponseOKType = OrgMembershipAsResponse;
export interface GetOrganizationMembershipForUserResponseOK extends GetOrganizationMembershipForUserResponseOKType {
}
declare type GetOrganizationMembershipForUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse;
export interface GetOrganizationMembershipForUserResponseError extends GetOrganizationMembershipForUserResponseErrorType {
}
export interface SetOrganizationMembershipForUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
    body: {
        /**
         * The role to give the user in the organization. Can be one of:
         * `admin` - The user will become an owner of the organization.
         * `member` - The user will become a non-owner member of the organization.
         */
        role?: "admin" | "member";
    };
}
declare type SetOrganizationMembershipForUserResponseOKType = OrgMembershipAsResponse;
export interface SetOrganizationMembershipForUserResponseOK extends SetOrganizationMembershipForUserResponseOKType {
}
declare type SetOrganizationMembershipForUserResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface SetOrganizationMembershipForUserResponseError extends SetOrganizationMembershipForUserResponseErrorType {
}
export interface RemoveOrganzationMembershipForUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
}
export declare type RemoveOrganzationMembershipForUserResponseOK = undefined;
declare type RemoveOrganzationMembershipForUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse;
export interface RemoveOrganzationMembershipForUserResponseError extends RemoveOrganzationMembershipForUserResponseErrorType {
}
export interface GetOrganizationMembershipsForAuthenticatedUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Indicates the state of the memberships to return. If not specified, the API returns both active and pending memberships.
     */
    state?: "active" | "pending";
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetOrganizationMembershipsForAuthenticatedUserResponseOKType = Array<OrgMembershipAsResponse>;
export interface GetOrganizationMembershipsForAuthenticatedUserResponseOK extends GetOrganizationMembershipsForAuthenticatedUserResponseOKType {
}
declare type GetOrganizationMembershipsForAuthenticatedUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface GetOrganizationMembershipsForAuthenticatedUserResponseError extends GetOrganizationMembershipsForAuthenticatedUserResponseErrorType {
}
export interface GetOrganizationMembershipForAuthenticatedUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
}
declare type GetOrganizationMembershipForAuthenticatedUserResponseOKType = OrgMembershipAsResponse;
export interface GetOrganizationMembershipForAuthenticatedUserResponseOK extends GetOrganizationMembershipForAuthenticatedUserResponseOKType {
}
declare type GetOrganizationMembershipForAuthenticatedUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse;
export interface GetOrganizationMembershipForAuthenticatedUserResponseError extends GetOrganizationMembershipForAuthenticatedUserResponseErrorType {
}
export interface UpdateOrganizationMembershipForAuthenticatedUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    body: {
        /**
         * The state that the membership should be in. Only `"active"` will be accepted.
         */
        state: "active";
    };
}
declare type UpdateOrganizationMembershipForAuthenticatedUserResponseOKType = OrgMembershipAsResponse;
export interface UpdateOrganizationMembershipForAuthenticatedUserResponseOK extends UpdateOrganizationMembershipForAuthenticatedUserResponseOKType {
}
declare type UpdateOrganizationMembershipForAuthenticatedUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface UpdateOrganizationMembershipForAuthenticatedUserResponseError extends UpdateOrganizationMembershipForAuthenticatedUserResponseErrorType {
}
export {};
//# sourceMappingURL=member.d.ts.map