/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PullRequestReviewAsResponse } from "../../definitions/PullRequestReviewAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ValidationErrorSimpleAsResponse } from "../../definitions/ValidationErrorSimpleAsResponse";
import { ReviewCommentAsResponse } from "../../definitions/ReviewCommentAsResponse";
export interface GetPullRequestReviewsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetPullRequestReviewsResponseOKType = Array<PullRequestReviewAsResponse>;
export interface GetPullRequestReviewsResponseOK extends GetPullRequestReviewsResponseOKType {
}
export declare type GetPullRequestReviewsResponseError = undefined;
export interface CreatePullRequestReviewRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    body: {
        /**
         * The SHA of the commit that needs a review. Not using the latest commit SHA may render your review comment outdated if a subsequent commit modifies the line you specify as the `position`. Defaults to the most recent commit in the pull request when you do not specify a value.
         */
        commit_id?: string;
        /**
         * **Required** when using `REQUEST_CHANGES` or `COMMENT` for the `event` parameter. The body text of the pull request review.
         */
        body?: string;
        /**
         * The review action you want to perform. The review actions include: `APPROVE`, `REQUEST_CHANGES`, or `COMMENT`. By leaving this blank, you set the review action state to `PENDING`, which means you will need to [submit the pull request review](https://docs.github.com/rest/pulls#submit-a-review-for-a-pull-request) when you are ready.
         */
        event?: "APPROVE" | "REQUEST_CHANGES" | "COMMENT";
        /**
         * Use the following table to specify the location, destination, and contents of the draft review comment.
         */
        comments?: Array<{
            /**
             * The relative path to the file that necessitates a review comment.
             */
            path: string;
            /**
             * The position in the diff where you want to add a review comment. Note this value is not the same as the line number in the file. For help finding the position value, read the note below.
             */
            position?: number;
            /**
             * Text of the review comment.
             */
            body: string;
            line?: number;
            side?: string;
            start_line?: number;
            start_side?: string;
        }>;
    };
}
declare type CreatePullRequestReviewResponseOKType = PullRequestReviewAsResponse;
export interface CreatePullRequestReviewResponseOK extends CreatePullRequestReviewResponseOKType {
}
declare type CreatePullRequestReviewResponseErrorType = BasicErrorAsResponse & ValidationErrorSimpleAsResponse;
export interface CreatePullRequestReviewResponseError extends CreatePullRequestReviewResponseErrorType {
}
export interface GetPullRequestReviewRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The unique identifier of the review.
     */
    review_id: number;
}
declare type GetPullRequestReviewResponseOKType = PullRequestReviewAsResponse;
export interface GetPullRequestReviewResponseOK extends GetPullRequestReviewResponseOKType {
}
declare type GetPullRequestReviewResponseErrorType = BasicErrorAsResponse;
export interface GetPullRequestReviewResponseError extends GetPullRequestReviewResponseErrorType {
}
export interface UpdatePullRequestReviewRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The unique identifier of the review.
     */
    review_id: number;
    body: {
        /**
         * The body text of the pull request review.
         */
        body: string;
    };
}
declare type UpdatePullRequestReviewResponseOKType = PullRequestReviewAsResponse;
export interface UpdatePullRequestReviewResponseOK extends UpdatePullRequestReviewResponseOKType {
}
declare type UpdatePullRequestReviewResponseErrorType = ValidationErrorSimpleAsResponse;
export interface UpdatePullRequestReviewResponseError extends UpdatePullRequestReviewResponseErrorType {
}
export interface DeletePullRequestReviewRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The unique identifier of the review.
     */
    review_id: number;
}
declare type DeletePullRequestReviewResponseOKType = PullRequestReviewAsResponse;
export interface DeletePullRequestReviewResponseOK extends DeletePullRequestReviewResponseOKType {
}
declare type DeletePullRequestReviewResponseErrorType = BasicErrorAsResponse & ValidationErrorSimpleAsResponse;
export interface DeletePullRequestReviewResponseError extends DeletePullRequestReviewResponseErrorType {
}
export interface GetCommentsForPullRequestReviewRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The unique identifier of the review.
     */
    review_id: number;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetCommentsForPullRequestReviewResponseOKType = Array<ReviewCommentAsResponse>;
export interface GetCommentsForPullRequestReviewResponseOK extends GetCommentsForPullRequestReviewResponseOKType {
}
declare type GetCommentsForPullRequestReviewResponseErrorType = BasicErrorAsResponse;
export interface GetCommentsForPullRequestReviewResponseError extends GetCommentsForPullRequestReviewResponseErrorType {
}
export interface DismissPullRequestReviewRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The unique identifier of the review.
     */
    review_id: number;
    body: {
        /**
         * The message for the pull request review dismissal
         */
        message: string;
        event?: "DISMISS";
    };
}
declare type DismissPullRequestReviewResponseOKType = PullRequestReviewAsResponse;
export interface DismissPullRequestReviewResponseOK extends DismissPullRequestReviewResponseOKType {
}
declare type DismissPullRequestReviewResponseErrorType = BasicErrorAsResponse & ValidationErrorSimpleAsResponse;
export interface DismissPullRequestReviewResponseError extends DismissPullRequestReviewResponseErrorType {
}
export interface SubmitPullRequestReviewRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The unique identifier of the review.
     */
    review_id: number;
    body: {
        /**
         * The body text of the pull request review
         */
        body?: string;
        /**
         * The review action you want to perform. The review actions include: `APPROVE`, `REQUEST_CHANGES`, or `COMMENT`. When you leave this blank, the API returns _HTTP 422 (Unrecognizable entity)_ and sets the review action state to `PENDING`, which means you will need to re-submit the pull request review using a review action.
         */
        event: "APPROVE" | "REQUEST_CHANGES" | "COMMENT";
    };
}
declare type SubmitPullRequestReviewResponseOKType = PullRequestReviewAsResponse;
export interface SubmitPullRequestReviewResponseOK extends SubmitPullRequestReviewResponseOKType {
}
declare type SubmitPullRequestReviewResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorSimpleAsResponse;
export interface SubmitPullRequestReviewResponseError extends SubmitPullRequestReviewResponseErrorType {
}
export {};
//# sourceMappingURL=review.d.ts.map