/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PullRequestReviewCommentAsResponse } from "../../../definitions/PullRequestReviewCommentAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BasicErrorAsResponse } from "../../../definitions/BasicErrorAsResponse";
import { ValidationErrorAsResponse } from "../../../definitions/ValidationErrorAsResponse";
export interface GetPullRequestReviewCommentInRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    sort?: "created" | "updated" | "created_at";
    /**
     * The direction to sort results. Ignored without `sort` parameter.
     */
    direction?: "asc" | "desc";
    /**
     * Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
     */
    since?: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetPullRequestReviewCommentInRepositoryResponseOKType = Array<PullRequestReviewCommentAsResponse>;
export interface GetPullRequestReviewCommentInRepositoryResponseOK extends GetPullRequestReviewCommentInRepositoryResponseOKType {
}
export declare type GetPullRequestReviewCommentInRepositoryResponseError = undefined;
export interface GetPullRequestReviewCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
}
declare type GetPullRequestReviewCommentResponseOKType = PullRequestReviewCommentAsResponse;
export interface GetPullRequestReviewCommentResponseOK extends GetPullRequestReviewCommentResponseOKType {
}
declare type GetPullRequestReviewCommentResponseErrorType = BasicErrorAsResponse;
export interface GetPullRequestReviewCommentResponseError extends GetPullRequestReviewCommentResponseErrorType {
}
export interface UpdatePullRequestReviewCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
    body: {
        /**
         * The text of the reply to the review comment.
         */
        body: string;
    };
}
declare type UpdatePullRequestReviewCommentResponseOKType = PullRequestReviewCommentAsResponse;
export interface UpdatePullRequestReviewCommentResponseOK extends UpdatePullRequestReviewCommentResponseOKType {
}
export declare type UpdatePullRequestReviewCommentResponseError = undefined;
export interface DeletePullRequestReviewCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
}
export declare type DeletePullRequestReviewCommentResponseOK = undefined;
declare type DeletePullRequestReviewCommentResponseErrorType = BasicErrorAsResponse;
export interface DeletePullRequestReviewCommentResponseError extends DeletePullRequestReviewCommentResponseErrorType {
}
export interface GetPullRequestReviewCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
     */
    sort?: "created" | "updated";
    /**
     * The direction to sort results. Ignored without `sort` parameter.
     */
    direction?: "asc" | "desc";
    /**
     * Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
     */
    since?: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetPullRequestReviewCommentsResponseOKType = Array<PullRequestReviewCommentAsResponse>;
export interface GetPullRequestReviewCommentsResponseOK extends GetPullRequestReviewCommentsResponseOKType {
}
export declare type GetPullRequestReviewCommentsResponseError = undefined;
export interface CreatePullRequestReviewCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    body: {
        /**
         * The text of the review comment.
         */
        body: string;
        /**
         * The SHA of the commit needing a comment. Not using the latest commit SHA may render your comment outdated if a subsequent commit modifies the line you specify as the `position`.
         */
        commit_id: string;
        /**
         * The relative path to the file that necessitates a comment.
         */
        path: string;
        /**
         * **This parameter is deprecated. Use `line` instead**. The position in the diff where you want to add a review comment. Note this value is not the same as the line number in the file. For help finding the position value, read the note above.
         */
        position?: number;
        /**
         * In a split diff view, the side of the diff that the pull request's changes appear on. Can be `LEFT` or `RIGHT`. Use `LEFT` for deletions that appear in red. Use `RIGHT` for additions that appear in green or unchanged lines that appear in white and are shown for context. For a multi-line comment, side represents whether the last line of the comment range is a deletion or addition. For more information, see "[Diff view options](https://docs.github.com/articles/about-comparing-branches-in-pull-requests#diff-view-options)" in the GitHub Help documentation.
         */
        side?: "LEFT" | "RIGHT";
        /**
         * The line of the blob in the pull request diff that the comment applies to. For a multi-line comment, the last line of the range that your comment applies to.
         */
        line: number;
        /**
         * **Required when using multi-line comments unless using `in_reply_to`**. The `start_line` is the first line in the pull request diff that your multi-line comment applies to. To learn more about multi-line comments, see "[Commenting on a pull request](https://docs.github.com/articles/commenting-on-a-pull-request#adding-line-comments-to-a-pull-request)" in the GitHub Help documentation.
         */
        start_line?: number;
        /**
         * **Required when using multi-line comments unless using `in_reply_to`**. The `start_side` is the starting side of the diff that the comment applies to. Can be `LEFT` or `RIGHT`. To learn more about multi-line comments, see "[Commenting on a pull request](https://docs.github.com/articles/commenting-on-a-pull-request#adding-line-comments-to-a-pull-request)" in the GitHub Help documentation. See `side` in this table for additional context.
         */
        start_side?: "LEFT" | "RIGHT" | "side";
        /**
         * The ID of the review comment to reply to. To find the ID of a review comment with ["List review comments on a pull request"](#list-review-comments-on-a-pull-request). When specified, all parameters other than `body` in the request body are ignored.
         */
        in_reply_to?: number;
    };
}
declare type CreatePullRequestReviewCommentResponseOKType = PullRequestReviewCommentAsResponse;
export interface CreatePullRequestReviewCommentResponseOK extends CreatePullRequestReviewCommentResponseOKType {
}
declare type CreatePullRequestReviewCommentResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreatePullRequestReviewCommentResponseError extends CreatePullRequestReviewCommentResponseErrorType {
}
export interface CreateReplyForPullRequestReviewCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number that identifies the pull request.
     */
    pull_number: number;
    /**
     * The unique identifier of the comment.
     */
    comment_id: number;
    body: {
        /**
         * The text of the review comment.
         */
        body: string;
    };
}
declare type CreateReplyForPullRequestReviewCommentResponseOKType = PullRequestReviewCommentAsResponse;
export interface CreateReplyForPullRequestReviewCommentResponseOK extends CreateReplyForPullRequestReviewCommentResponseOKType {
}
declare type CreateReplyForPullRequestReviewCommentResponseErrorType = BasicErrorAsResponse;
export interface CreateReplyForPullRequestReviewCommentResponseError extends CreateReplyForPullRequestReviewCommentResponseErrorType {
}
export {};
//# sourceMappingURL=comment.d.ts.map