/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { MinimalRepositoryAsResponse } from "../definitions/MinimalRepositoryAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { RepositoryAsResponse } from "../definitions/RepositoryAsResponse";
import { BasicErrorAsResponse } from "../definitions/BasicErrorAsResponse";
import { ValidationErrorAsResponse } from "../definitions/ValidationErrorAsResponse";
import { FullRepositoryAsResponse } from "../definitions/FullRepositoryAsResponse";
import { CodeownersErrorsAsResponse } from "../definitions/CodeownersErrorsAsResponse";
import { ContributorAsResponse } from "../definitions/ContributorAsResponse";
import { LanguageAsResponse } from "../definitions/LanguageAsResponse";
import { TagAsResponse } from "../definitions/TagAsResponse";
import { TeamAsResponse } from "../definitions/TeamAsResponse";
import { TopicAsResponse } from "../definitions/TopicAsResponse";
import { ValidationErrorSimpleAsResponse } from "../definitions/ValidationErrorSimpleAsResponse";
export interface GetOrganizationRepositoriesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    /**
     * Specifies the types of repositories you want returned.
     */
    type?: "all" | "public" | "private" | "forks" | "sources" | "member";
    /**
     * The property to sort the results by.
     */
    sort?: "created" | "updated" | "pushed" | "full_name";
    /**
     * The order to sort by. Default: `asc` when using `full_name`, otherwise `desc`.
     */
    direction?: "asc" | "desc";
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetOrganizationRepositoriesResponseOKType = Array<MinimalRepositoryAsResponse>;
export interface GetOrganizationRepositoriesResponseOK extends GetOrganizationRepositoriesResponseOKType {
}
export declare type GetOrganizationRepositoriesResponseError = undefined;
export interface CreateOrganizationRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The organization name. The name is not case sensitive.
     */
    org: string;
    body: {
        /**
         * The name of the repository.
         */
        name: string;
        /**
         * A short description of the repository.
         */
        description?: string;
        /**
         * A URL with more information about the repository.
         */
        homepage?: string;
        /**
         * Whether the repository is private.
         */
        private?: boolean;
        /**
         * The visibility of the repository.
         */
        visibility?: "public" | "private";
        /**
         * Either `true` to enable issues for this repository or `false` to disable them.
         */
        has_issues?: boolean;
        /**
         * Either `true` to enable projects for this repository or `false` to disable them. **Note:** If you're creating a repository in an organization that has disabled repository projects, the default is `false`, and if you pass `true`, the API returns an error.
         */
        has_projects?: boolean;
        /**
         * Either `true` to enable the wiki for this repository or `false` to disable it.
         */
        has_wiki?: boolean;
        /**
         * Whether downloads are enabled.
         */
        has_downloads?: boolean;
        /**
         * Either `true` to make this repo available as a template repository or `false` to prevent it.
         */
        is_template?: boolean;
        /**
         * The id of the team that will be granted access to this repository. This is only valid when creating a repository in an organization.
         */
        team_id?: number;
        /**
         * Pass `true` to create an initial commit with empty README.
         */
        auto_init?: boolean;
        /**
         * Desired language or platform [.gitignore template](https://github.com/github/gitignore) to apply. Use the name of the template without the extension. For example, "Haskell".
         */
        gitignore_template?: string;
        /**
         * Choose an [open source license template](https://choosealicense.com/) that best suits your needs, and then use the [license keyword](https://docs.github.com/articles/licensing-a-repository/#searching-github-by-license-type) as the `license_template` string. For example, "mit" or "mpl-2.0".
         */
        license_template?: string;
        /**
         * Either `true` to allow squash-merging pull requests, or `false` to prevent squash-merging.
         */
        allow_squash_merge?: boolean;
        /**
         * Either `true` to allow merging pull requests with a merge commit, or `false` to prevent merging pull requests with merge commits.
         */
        allow_merge_commit?: boolean;
        /**
         * Either `true` to allow rebase-merging pull requests, or `false` to prevent rebase-merging.
         */
        allow_rebase_merge?: boolean;
        /**
         * Either `true` to allow auto-merge on pull requests, or `false` to disallow auto-merge.
         */
        allow_auto_merge?: boolean;
        /**
         * Either `true` to allow automatically deleting head branches when pull requests are merged, or `false` to prevent automatic deletion. **The authenticated user must be an organization owner to set this property to `true`.**
         */
        delete_branch_on_merge?: boolean;
        /**
         * Either `true` to allow squash-merge commits to use pull request title, or `false` to use commit message. **This property has been deprecated. Please use `squash_merge_commit_title` instead.
         */
        use_squash_pr_title_as_default?: boolean;
        /**
    * The default value for a squash merge commit title:
    
    - `PR_TITLE` - default to the pull request's title.
    - `COMMIT_OR_PR_TITLE` - default to the commit's title (if only one commit) or the pull request's title (when more than one commit).
    */
        squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE";
        /**
    * The default value for a squash merge commit message:
    
    - `PR_BODY` - default to the pull request's body.
    - `COMMIT_MESSAGES` - default to the branch's commit messages.
    - `BLANK` - default to a blank commit message.
    */
        squash_merge_commit_message?: "PR_BODY" | "COMMIT_MESSAGES" | "BLANK";
        /**
    * The default value for a merge commit title.
    
    - `PR_TITLE` - default to the pull request's title.
    - `MERGE_MESSAGE` - default to the classic title for a merge message (e.g., Merge pull request #123 from branch-name).
    */
        merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE";
        /**
    * The default value for a merge commit message.
    
    - `PR_TITLE` - default to the pull request's title.
    - `PR_BODY` - default to the pull request's body.
    - `BLANK` - default to a blank commit message.
    */
        merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK";
    };
}
declare type CreateOrganizationRepositoryResponseOKType = RepositoryAsResponse;
export interface CreateOrganizationRepositoryResponseOK extends CreateOrganizationRepositoryResponseOKType {
}
declare type CreateOrganizationRepositoryResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateOrganizationRepositoryResponseError extends CreateOrganizationRepositoryResponseErrorType {
}
export interface GetRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
declare type GetRepositoryResponseOKType = FullRepositoryAsResponse;
export interface GetRepositoryResponseOK extends GetRepositoryResponseOKType {
}
declare type GetRepositoryResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse;
export interface GetRepositoryResponseError extends GetRepositoryResponseErrorType {
}
export interface UpdateRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * The name of the repository.
         */
        name?: string;
        /**
         * A short description of the repository.
         */
        description?: string;
        /**
         * A URL with more information about the repository.
         */
        homepage?: string;
        /**
         * Either `true` to make the repository private or `false` to make it public. Default: `false`.
         **Note**: You will get a `422` error if the organization restricts [changing repository visibility](https://docs.github.com/articles/repository-permission-levels-for-an-organization#changing-the-visibility-of-repositories) to organization owners and a non-owner tries to change the value of private.
         */
        private?: boolean;
        /**
         * The visibility of the repository.
         */
        visibility?: "public" | "private";
        /**
    * Specify which security and analysis features to enable or disable for the repository.
    
    To use this parameter, you must have admin permissions for the repository or be an owner or security manager for the organization that owns the repository. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
    
    For example, to enable GitHub Advanced Security, use this data in the body of the `PATCH` request:
    `{ "security_and_analysis": {"advanced_security": { "status": "enabled" } } }`.
    
    You can check which security and analysis features are currently enabled by using a `GET /repos/{owner}/{repo}` request.
    */
        security_and_analysis?: {
            /**
             * Use the `status` property to enable or disable GitHub Advanced Security for this repository. For more information, see "[About GitHub Advanced Security](/github/getting-started-with-github/learning-about-github/about-github-advanced-security)."
             */
            advanced_security?: {
                /**
                 * Can be `enabled` or `disabled`.
                 */
                status?: string;
            };
            /**
             * Use the `status` property to enable or disable secret scanning for this repository. For more information, see "[About secret scanning](/code-security/secret-security/about-secret-scanning)."
             */
            secret_scanning?: {
                /**
                 * Can be `enabled` or `disabled`.
                 */
                status?: string;
            };
            /**
             * Use the `status` property to enable or disable secret scanning push protection for this repository. For more information, see "[Protecting pushes with secret scanning](/code-security/secret-scanning/protecting-pushes-with-secret-scanning)."
             */
            secret_scanning_push_protection?: {
                /**
                 * Can be `enabled` or `disabled`.
                 */
                status?: string;
            };
        } | null;
        /**
         * Either `true` to enable issues for this repository or `false` to disable them.
         */
        has_issues?: boolean;
        /**
         * Either `true` to enable projects for this repository or `false` to disable them. **Note:** If you're creating a repository in an organization that has disabled repository projects, the default is `false`, and if you pass `true`, the API returns an error.
         */
        has_projects?: boolean;
        /**
         * Either `true` to enable the wiki for this repository or `false` to disable it.
         */
        has_wiki?: boolean;
        /**
         * Either `true` to make this repo available as a template repository or `false` to prevent it.
         */
        is_template?: boolean;
        /**
         * Updates the default branch for this repository.
         */
        default_branch?: string;
        /**
         * Either `true` to allow squash-merging pull requests, or `false` to prevent squash-merging.
         */
        allow_squash_merge?: boolean;
        /**
         * Either `true` to allow merging pull requests with a merge commit, or `false` to prevent merging pull requests with merge commits.
         */
        allow_merge_commit?: boolean;
        /**
         * Either `true` to allow rebase-merging pull requests, or `false` to prevent rebase-merging.
         */
        allow_rebase_merge?: boolean;
        /**
         * Either `true` to allow auto-merge on pull requests, or `false` to disallow auto-merge.
         */
        allow_auto_merge?: boolean;
        /**
         * Either `true` to allow automatically deleting head branches when pull requests are merged, or `false` to prevent automatic deletion.
         */
        delete_branch_on_merge?: boolean;
        /**
         * Either `true` to always allow a pull request head branch that is behind its base branch to be updated even if it is not required to be up to date before merging, or false otherwise.
         */
        allow_update_branch?: boolean;
        /**
         * Either `true` to allow squash-merge commits to use pull request title, or `false` to use commit message. **This property has been deprecated. Please use `squash_merge_commit_title` instead.
         */
        use_squash_pr_title_as_default?: boolean;
        /**
    * The default value for a squash merge commit title:
    
    - `PR_TITLE` - default to the pull request's title.
    - `COMMIT_OR_PR_TITLE` - default to the commit's title (if only one commit) or the pull request's title (when more than one commit).
    */
        squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE";
        /**
    * The default value for a squash merge commit message:
    
    - `PR_BODY` - default to the pull request's body.
    - `COMMIT_MESSAGES` - default to the branch's commit messages.
    - `BLANK` - default to a blank commit message.
    */
        squash_merge_commit_message?: "PR_BODY" | "COMMIT_MESSAGES" | "BLANK";
        /**
    * The default value for a merge commit title.
    
    - `PR_TITLE` - default to the pull request's title.
    - `MERGE_MESSAGE` - default to the classic title for a merge message (e.g., Merge pull request #123 from branch-name).
    */
        merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE";
        /**
    * The default value for a merge commit message.
    
    - `PR_TITLE` - default to the pull request's title.
    - `PR_BODY` - default to the pull request's body.
    - `BLANK` - default to a blank commit message.
    */
        merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK";
        /**
         * Whether to archive this repository. `false` will unarchive a previously archived repository.
         */
        archived?: boolean;
        /**
         * Either `true` to allow private forks, or `false` to prevent private forks.
         */
        allow_forking?: boolean;
        /**
         * Either `true` to require contributors to sign off on web-based commits, or `false` to not require contributors to sign off on web-based commits.
         */
        web_commit_signoff_required?: boolean;
    };
}
declare type UpdateRepositoryResponseOKType = FullRepositoryAsResponse;
export interface UpdateRepositoryResponseOK extends UpdateRepositoryResponseOKType {
}
declare type UpdateRepositoryResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface UpdateRepositoryResponseError extends UpdateRepositoryResponseErrorType {
}
export interface DeleteRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
export declare type DeleteRepositoryResponseOK = undefined;
declare type DeleteRepositoryResponseErrorType = BasicErrorAsResponse & {
    message?: string;
    documentation_url?: string;
} & BasicErrorAsResponse;
export interface DeleteRepositoryResponseError extends DeleteRepositoryResponseErrorType {
}
export interface EnableAutomatedSecurityFixesForRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
export declare type EnableAutomatedSecurityFixesForRepositoryResponseOK = undefined;
export declare type EnableAutomatedSecurityFixesForRepositoryResponseError = undefined;
export interface DisableAutomatedSecurityFixesForRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
export declare type DisableAutomatedSecurityFixesForRepositoryResponseOK = undefined;
export declare type DisableAutomatedSecurityFixesForRepositoryResponseError = undefined;
export interface GetRepositoryCodeOwnersErrorsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * A branch, tag or commit name used to determine which version of the CODEOWNERS file to use. Default: the repository's default branch (e.g. `main`)
     */
    ref?: string;
}
declare type GetRepositoryCodeOwnersErrorsResponseOKType = CodeownersErrorsAsResponse;
export interface GetRepositoryCodeOwnersErrorsResponseOK extends GetRepositoryCodeOwnersErrorsResponseOKType {
}
export declare type GetRepositoryCodeOwnersErrorsResponseError = undefined;
export interface GetRepositoryContributorsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * Set to `1` or `true` to include anonymous contributors in results.
     */
    anon?: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetRepositoryContributorsResponseOKType = Array<ContributorAsResponse>;
export interface GetRepositoryContributorsResponseOK extends GetRepositoryContributorsResponseOKType {
}
declare type GetRepositoryContributorsResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse;
export interface GetRepositoryContributorsResponseError extends GetRepositoryContributorsResponseErrorType {
}
export interface CreateRepositoryDispatchEventRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * A custom webhook event name. Must be 100 characters or fewer.
         */
        event_type: string;
        /**
         * JSON payload with extra information about the webhook event that your action or workflow may use. The maximum number of top-level properties is 10.
         */
        client_payload?: {
            [x: string]: any;
        };
    };
}
export declare type CreateRepositoryDispatchEventResponseOK = undefined;
declare type CreateRepositoryDispatchEventResponseErrorType = ValidationErrorAsResponse;
export interface CreateRepositoryDispatchEventResponseError extends CreateRepositoryDispatchEventResponseErrorType {
}
export interface GetRepositoryLanguagesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
declare type GetRepositoryLanguagesResponseOKType = LanguageAsResponse;
export interface GetRepositoryLanguagesResponseOK extends GetRepositoryLanguagesResponseOKType {
}
export declare type GetRepositoryLanguagesResponseError = undefined;
export interface GetRepositoryTagsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetRepositoryTagsResponseOKType = Array<TagAsResponse>;
export interface GetRepositoryTagsResponseOK extends GetRepositoryTagsResponseOKType {
}
export declare type GetRepositoryTagsResponseError = undefined;
export interface GetRepositoryTeamsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetRepositoryTeamsResponseOKType = Array<TeamAsResponse>;
export interface GetRepositoryTeamsResponseOK extends GetRepositoryTeamsResponseOKType {
}
export declare type GetRepositoryTeamsResponseError = undefined;
export interface GetRepositoryTopicsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
}
declare type GetRepositoryTopicsResponseOKType = TopicAsResponse;
export interface GetRepositoryTopicsResponseOK extends GetRepositoryTopicsResponseOKType {
}
declare type GetRepositoryTopicsResponseErrorType = BasicErrorAsResponse;
export interface GetRepositoryTopicsResponseError extends GetRepositoryTopicsResponseErrorType {
}
export interface ReplaceRepositoryTopicsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * An array of topics to add to the repository. Pass one or more topics to _replace_ the set of existing topics. Send an empty array (`[]`) to clear all topics from the repository. **Note:** Topic `names` cannot contain uppercase letters.
         */
        names: Array<string>;
    };
}
declare type ReplaceRepositoryTopicsResponseOKType = TopicAsResponse;
export interface ReplaceRepositoryTopicsResponseOK extends ReplaceRepositoryTopicsResponseOKType {
}
declare type ReplaceRepositoryTopicsResponseErrorType = BasicErrorAsResponse & ValidationErrorSimpleAsResponse;
export interface ReplaceRepositoryTopicsResponseError extends ReplaceRepositoryTopicsResponseErrorType {
}
export interface TransferRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * The username or organization name the repository will be transferred to.
         */
        new_owner: string;
        /**
         * The new name to be given to the repository.
         */
        new_name?: string;
        /**
         * ID of the team or teams to add to the repository. Teams can only be added to organization-owned repositories.
         */
        team_ids?: Array<number>;
    };
}
declare type TransferRepositoryResponseOKType = MinimalRepositoryAsResponse;
export interface TransferRepositoryResponseOK extends TransferRepositoryResponseOKType {
}
export declare type TransferRepositoryResponseError = undefined;
export interface IsRepositoryVulnerabilityAlertsEnabledRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
export declare type IsRepositoryVulnerabilityAlertsEnabledResponseOK = undefined;
export declare type IsRepositoryVulnerabilityAlertsEnabledResponseError = undefined;
export interface EnabledRepositoryVulnerabilityAlertsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
export declare type EnabledRepositoryVulnerabilityAlertsResponseOK = undefined;
export declare type EnabledRepositoryVulnerabilityAlertsResponseError = undefined;
export interface DisableRepositoryVulnerabilityAlertsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
}
export declare type DisableRepositoryVulnerabilityAlertsResponseOK = undefined;
export declare type DisableRepositoryVulnerabilityAlertsResponseError = undefined;
export interface CreateRepositoryFromTemplateRequest extends HeadersOption, ErrorStrategyOption {
    template_owner: string;
    template_repo: string;
    body: {
        /**
         * The organization or person who will own the new repository. To create a new repository in an organization, the authenticated user must be a member of the specified organization.
         */
        owner?: string;
        /**
         * The name of the new repository.
         */
        name: string;
        /**
         * A short description of the new repository.
         */
        description?: string;
        /**
         * Set to `true` to include the directory structure and files from all branches in the template repository, and not just the default branch. Default: `false`.
         */
        include_all_branches?: boolean;
        /**
         * Either `true` to create a new private repository or `false` to create a new public one.
         */
        private?: boolean;
    };
}
declare type CreateRepositoryFromTemplateResponseOKType = RepositoryAsResponse;
export interface CreateRepositoryFromTemplateResponseOK extends CreateRepositoryFromTemplateResponseOKType {
}
export declare type CreateRepositoryFromTemplateResponseError = undefined;
export interface GetPublicRepositoriesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A repository ID. Only return repositories with an ID greater than this ID.
     */
    since?: number;
}
declare type GetPublicRepositoriesResponseOKType = Array<MinimalRepositoryAsResponse>;
export interface GetPublicRepositoriesResponseOK extends GetPublicRepositoriesResponseOKType {
}
declare type GetPublicRepositoriesResponseErrorType = ValidationErrorAsResponse;
export interface GetPublicRepositoriesResponseError extends GetPublicRepositoriesResponseErrorType {
}
export interface GetRepositoriesForAuthenticatedUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Limit results to repositories with the specified visibility.
     */
    visibility?: "all" | "public" | "private";
    /**
     * Comma-separated list of values. Can include:
     * `owner`: Repositories that are owned by the authenticated user.
     * `collaborator`: Repositories that the user has been added to as a collaborator.
     * `organization_member`: Repositories that the user has access to through being a member of an organization. This includes every repository on every team that the user is on.
     */
    affiliation?: string;
    /**
     * Limit results to repositories of the specified type. Will cause a `422` error if used in the same request as **visibility** or **affiliation**.
     */
    type?: "all" | "owner" | "public" | "private" | "member";
    /**
     * The property to sort the results by.
     */
    sort?: "created" | "updated" | "pushed" | "full_name";
    /**
     * The order to sort by. Default: `asc` when using `full_name`, otherwise `desc`.
     */
    direction?: "asc" | "desc";
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
    /**
     * Only show repositories updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
     */
    since?: string;
    /**
     * Only show repositories updated before the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
     */
    before?: string;
}
declare type GetRepositoriesForAuthenticatedUserResponseOKType = Array<RepositoryAsResponse>;
export interface GetRepositoriesForAuthenticatedUserResponseOK extends GetRepositoriesForAuthenticatedUserResponseOKType {
}
declare type GetRepositoriesForAuthenticatedUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface GetRepositoriesForAuthenticatedUserResponseError extends GetRepositoriesForAuthenticatedUserResponseErrorType {
}
export interface CreateRepositoryForAuthenticatedUserRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
         * The name of the repository.
         */
        name: string;
        /**
         * A short description of the repository.
         */
        description?: string;
        /**
         * A URL with more information about the repository.
         */
        homepage?: string;
        /**
         * Whether the repository is private.
         */
        private?: boolean;
        /**
         * Whether issues are enabled.
         */
        has_issues?: boolean;
        /**
         * Whether projects are enabled.
         */
        has_projects?: boolean;
        /**
         * Whether the wiki is enabled.
         */
        has_wiki?: boolean;
        /**
         * Whether discussions are enabled.
         */
        has_discussions?: boolean;
        /**
         * The id of the team that will be granted access to this repository. This is only valid when creating a repository in an organization.
         */
        team_id?: number;
        /**
         * Whether the repository is initialized with a minimal README.
         */
        auto_init?: boolean;
        /**
         * The desired language or platform to apply to the .gitignore.
         */
        gitignore_template?: string;
        /**
         * The license keyword of the open source license for this repository.
         */
        license_template?: string;
        /**
         * Whether to allow squash merges for pull requests.
         */
        allow_squash_merge?: boolean;
        /**
         * Whether to allow merge commits for pull requests.
         */
        allow_merge_commit?: boolean;
        /**
         * Whether to allow rebase merges for pull requests.
         */
        allow_rebase_merge?: boolean;
        /**
         * Whether to allow Auto-merge to be used on pull requests.
         */
        allow_auto_merge?: boolean;
        /**
         * Whether to delete head branches when pull requests are merged
         */
        delete_branch_on_merge?: boolean;
        /**
    * The default value for a squash merge commit title:
    
    - `PR_TITLE` - default to the pull request's title.
    - `COMMIT_OR_PR_TITLE` - default to the commit's title (if only one commit) or the pull request's title (when more than one commit).
    */
        squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE";
        /**
    * The default value for a squash merge commit message:
    
    - `PR_BODY` - default to the pull request's body.
    - `COMMIT_MESSAGES` - default to the branch's commit messages.
    - `BLANK` - default to a blank commit message.
    */
        squash_merge_commit_message?: "PR_BODY" | "COMMIT_MESSAGES" | "BLANK";
        /**
    * The default value for a merge commit title.
    
    - `PR_TITLE` - default to the pull request's title.
    - `MERGE_MESSAGE` - default to the classic title for a merge message (e.g., Merge pull request #123 from branch-name).
    */
        merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE";
        /**
    * The default value for a merge commit message.
    
    - `PR_TITLE` - default to the pull request's title.
    - `PR_BODY` - default to the pull request's body.
    - `BLANK` - default to a blank commit message.
    */
        merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK";
        /**
         * Whether downloads are enabled.
         */
        has_downloads?: boolean;
        /**
         * Whether this repository acts as a template that can be used to generate new repositories.
         */
        is_template?: boolean;
    };
}
declare type CreateRepositoryForAuthenticatedUserResponseOKType = RepositoryAsResponse;
export interface CreateRepositoryForAuthenticatedUserResponseOK extends CreateRepositoryForAuthenticatedUserResponseOKType {
}
declare type CreateRepositoryForAuthenticatedUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateRepositoryForAuthenticatedUserResponseError extends CreateRepositoryForAuthenticatedUserResponseErrorType {
}
export interface GetRepositoriesForUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The handle for the GitHub user account.
     */
    username: string;
    /**
     * Limit results to repositories of the specified type.
     */
    type?: "all" | "owner" | "member";
    /**
     * The property to sort the results by.
     */
    sort?: "created" | "updated" | "pushed" | "full_name";
    /**
     * The order to sort by. Default: `asc` when using `full_name`, otherwise `desc`.
     */
    direction?: "asc" | "desc";
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetRepositoriesForUserResponseOKType = Array<MinimalRepositoryAsResponse>;
export interface GetRepositoriesForUserResponseOK extends GetRepositoriesForUserResponseOKType {
}
export declare type GetRepositoriesForUserResponseError = undefined;
export {};
//# sourceMappingURL=repository.d.ts.map