/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CollaboratorAsResponse } from "../../definitions/CollaboratorAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { RepositoryInvitationAsResponse } from "../../definitions/RepositoryInvitationAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
import { RepositoryCollaboratorPermissionAsResponse } from "../../definitions/RepositoryCollaboratorPermissionAsResponse";
export interface GetRepositoryCollaboratorsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * Filter collaborators returned by their affiliation. `outside` means all outside collaborators of an organization-owned repository. `direct` means all collaborators with permissions to an organization-owned repository, regardless of organization membership status. `all` means all collaborators the authenticated user can see.
     */
    affiliation?: "outside" | "direct" | "all";
    /**
     * Filter collaborators by the permissions they have on the repository. If not specified, all collaborators will be returned.
     */
    permission?: "pull" | "triage" | "push" | "maintain" | "admin";
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetRepositoryCollaboratorsResponseOKType = Array<CollaboratorAsResponse>;
export interface GetRepositoryCollaboratorsResponseOK extends GetRepositoryCollaboratorsResponseOKType {
}
declare type GetRepositoryCollaboratorsResponseErrorType = BasicErrorAsResponse;
export interface GetRepositoryCollaboratorsResponseError extends GetRepositoryCollaboratorsResponseErrorType {
}
export interface IsUserRepositoryCollaboratorRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
}
export declare type IsUserRepositoryCollaboratorResponseOK = undefined;
export declare type IsUserRepositoryCollaboratorResponseError = undefined;
export interface AddRepositoryCollaboratorRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
    body: {
        /**
         * The permission to grant the collaborator. **Only valid on organization-owned repositories.** We accept the following permissions to be set: `pull`, `triage`, `push`, `maintain`, `admin` and you can also specify a custom repository role name, if the owning organization has defined any.
         */
        permission?: string;
    };
}
declare type AddRepositoryCollaboratorResponseOKType = RepositoryInvitationAsResponse;
export interface AddRepositoryCollaboratorResponseOK extends AddRepositoryCollaboratorResponseOKType {
}
declare type AddRepositoryCollaboratorResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface AddRepositoryCollaboratorResponseError extends AddRepositoryCollaboratorResponseErrorType {
}
export interface RemoveRepositoryCollaboratorRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
}
export declare type RemoveRepositoryCollaboratorResponseOK = undefined;
export declare type RemoveRepositoryCollaboratorResponseError = undefined;
export interface GetRepositoryPermissionsForUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The handle for the GitHub user account.
     */
    username: string;
}
declare type GetRepositoryPermissionsForUserResponseOKType = RepositoryCollaboratorPermissionAsResponse;
export interface GetRepositoryPermissionsForUserResponseOK extends GetRepositoryPermissionsForUserResponseOKType {
}
declare type GetRepositoryPermissionsForUserResponseErrorType = BasicErrorAsResponse;
export interface GetRepositoryPermissionsForUserResponseError extends GetRepositoryPermissionsForUserResponseErrorType {
}
export {};
//# sourceMappingURL=collaborator.d.ts.map