/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { RepositoryInvitationAsResponse } from "../../../definitions/RepositoryInvitationAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BasicErrorAsResponse } from "../../../definitions/BasicErrorAsResponse";
export interface GetRepositoryInvitationsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetRepositoryInvitationsResponseOKType = Array<RepositoryInvitationAsResponse>;
export interface GetRepositoryInvitationsResponseOK extends GetRepositoryInvitationsResponseOKType {
}
export declare type GetRepositoryInvitationsResponseError = undefined;
export interface UpdateRepositoryInvitationRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the invitation.
     */
    invitation_id: number;
    body: {
        /**
         * The permissions that the associated user will have on the repository. Valid values are `read`, `write`, `maintain`, `triage`, and `admin`.
         */
        permissions?: "read" | "write" | "maintain" | "triage" | "admin";
    };
}
declare type UpdateRepositoryInvitationResponseOKType = RepositoryInvitationAsResponse;
export interface UpdateRepositoryInvitationResponseOK extends UpdateRepositoryInvitationResponseOKType {
}
export declare type UpdateRepositoryInvitationResponseError = undefined;
export interface DeleteInvitationRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The unique identifier of the invitation.
     */
    invitation_id: number;
}
export declare type DeleteInvitationResponseOK = undefined;
export declare type DeleteInvitationResponseError = undefined;
export interface GetRepositoryInvitationsForAuthenticatedUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetRepositoryInvitationsForAuthenticatedUserResponseOKType = Array<RepositoryInvitationAsResponse>;
export interface GetRepositoryInvitationsForAuthenticatedUserResponseOK extends GetRepositoryInvitationsForAuthenticatedUserResponseOKType {
}
declare type GetRepositoryInvitationsForAuthenticatedUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse;
export interface GetRepositoryInvitationsForAuthenticatedUserResponseError extends GetRepositoryInvitationsForAuthenticatedUserResponseErrorType {
}
export interface AcceptRepositoryInvitationRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The unique identifier of the invitation.
     */
    invitation_id: number;
}
export declare type AcceptRepositoryInvitationResponseOK = undefined;
declare type AcceptRepositoryInvitationResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse;
export interface AcceptRepositoryInvitationResponseError extends AcceptRepositoryInvitationResponseErrorType {
}
export interface DeclineRepositoryInvitationRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The unique identifier of the invitation.
     */
    invitation_id: number;
}
export declare type DeclineRepositoryInvitationResponseOK = undefined;
declare type DeclineRepositoryInvitationResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse;
export interface DeclineRepositoryInvitationResponseError extends DeclineRepositoryInvitationResponseErrorType {
}
export {};
//# sourceMappingURL=invitation.d.ts.map