/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from "@managed-api/commons-core";
import { ErrorStrategyOption } from "../../errorStrategy";
import { ContentTreeAsResponse } from "../../definitions/ContentTreeAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { FileCommitAsResponse } from "../../definitions/FileCommitAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
import { ContentFileAsResponse } from "../../definitions/ContentFileAsResponse";
export interface GetRepositoryContentRequest extends HeadersOption, ErrorStrategyOption {
    owner: string;
    repo: string;
    /**
     * path parameter
     */
    path: string;
    /**
     * The name of the commit/branch/tag. Default: the repository’s default branch (usually `master`)
     */
    ref?: string;
}
export declare type GetRepositoryContentResponseOK = Array<ContentTreeAsResponse> | ContentTreeAsResponse;
export interface GetRepositoryContentResponseError extends BasicErrorAsResponse {
}
export interface CreateOrUpdateFileContentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * path parameter
     */
    path: string;
    body: {
        /**
         * The commit message.
         */
        message: string;
        /**
         * The new file content, using Base64 encoding.
         */
        content: string;
        /**
         * **Required if you are updating a file**. The blob SHA of the file being replaced.
         */
        sha?: string;
        /**
         * The branch name. Default: the repository’s default branch (usually `master`)
         */
        branch?: string;
        /**
         * The person that committed the file. Default: the authenticated user.
         */
        committer?: {
            /**
             * The name of the author or committer of the commit. You'll receive a `422` status code if `name` is omitted.
             */
            name: string;
            /**
             * The email of the author or committer of the commit. You'll receive a `422` status code if `email` is omitted.
             */
            email: string;
            date?: string;
        };
        /**
         * The author of the file. Default: The `committer` or the authenticated user if you omit `committer`.
         */
        author?: {
            /**
             * The name of the author or committer of the commit. You'll receive a `422` status code if `name` is omitted.
             */
            name: string;
            /**
             * The email of the author or committer of the commit. You'll receive a `422` status code if `email` is omitted.
             */
            email: string;
            date?: string;
        };
    };
}
declare type CreateOrUpdateFileContentsResponseOKType = FileCommitAsResponse & FileCommitAsResponse;
export interface CreateOrUpdateFileContentsResponseOK extends CreateOrUpdateFileContentsResponseOKType {
}
declare type CreateOrUpdateFileContentsResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateOrUpdateFileContentsResponseError extends CreateOrUpdateFileContentsResponseErrorType {
}
export interface DeleteFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * path parameter
     */
    path: string;
    body: {
        /**
         * The commit message.
         */
        message: string;
        /**
         * The blob SHA of the file being deleted.
         */
        sha: string;
        /**
         * The branch name. Default: the repository’s default branch (usually `master`)
         */
        branch?: string;
        /**
         * object containing information about the committer.
         */
        committer?: {
            /**
             * The name of the author (or committer) of the commit
             */
            name?: string;
            /**
             * The email of the author (or committer) of the commit
             */
            email?: string;
        };
        /**
         * object containing information about the author.
         */
        author?: {
            /**
             * The name of the author (or committer) of the commit
             */
            name?: string;
            /**
             * The email of the author (or committer) of the commit
             */
            email?: string;
        };
    };
}
declare type DeleteFileResponseOKType = FileCommitAsResponse;
export interface DeleteFileResponseOK extends DeleteFileResponseOKType {
}
declare type DeleteFileResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse & {
    code?: string;
    message?: string;
    documentation_url?: string;
};
export interface DeleteFileResponseError extends DeleteFileResponseErrorType {
}
export interface GetRepositoryReadmeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The name of the commit/branch/tag. Default: the repository’s default branch (usually `master`)
     */
    ref?: string;
}
declare type GetRepositoryReadmeResponseOKType = ContentFileAsResponse;
export interface GetRepositoryReadmeResponseOK extends GetRepositoryReadmeResponseOKType {
}
declare type GetRepositoryReadmeResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface GetRepositoryReadmeResponseError extends GetRepositoryReadmeResponseErrorType {
}
export interface GetRepositoryReadmeForDirectoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The alternate path to look for a README file
     */
    dir: string;
    /**
     * The name of the commit/branch/tag. Default: the repository’s default branch (usually `master`)
     */
    ref?: string;
}
declare type GetRepositoryReadmeForDirectoryResponseOKType = ContentFileAsResponse;
export interface GetRepositoryReadmeForDirectoryResponseOK extends GetRepositoryReadmeForDirectoryResponseOKType {
}
declare type GetRepositoryReadmeForDirectoryResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface GetRepositoryReadmeForDirectoryResponseError extends GetRepositoryReadmeForDirectoryResponseErrorType {
}
export {};
//# sourceMappingURL=content.d.ts.map