/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { MinimalRepositoryAsResponse } from "../../definitions/MinimalRepositoryAsResponse";
import { BasicErrorAsResponse } from "../../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { FullRepositoryAsResponse } from "../../definitions/FullRepositoryAsResponse";
import { ValidationErrorAsResponse } from "../../definitions/ValidationErrorAsResponse";
export interface GetRepositoryForksRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    /**
     * The sort order. `stargazers` will sort by star count.
     */
    sort?: "newest" | "oldest" | "stargazers" | "watchers";
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
    /**
     * Page number of the results to fetch.
     */
    page?: number;
}
declare type GetRepositoryForksResponseOKType = Array<MinimalRepositoryAsResponse>;
export interface GetRepositoryForksResponseOK extends GetRepositoryForksResponseOKType {
}
declare type GetRepositoryForksResponseErrorType = BasicErrorAsResponse;
export interface GetRepositoryForksResponseError extends GetRepositoryForksResponseErrorType {
}
export interface CreateRepositoryForkRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account owner of the repository. The name is not case sensitive.
     */
    owner: string;
    /**
     * The name of the repository. The name is not case sensitive.
     */
    repo: string;
    body: {
        /**
         * Optional parameter to specify the organization name if forking into an organization.
         */
        organization?: string;
        /**
         * When forking from an existing repository, a new name for the fork.
         */
        name?: string;
        /**
         * When forking from an existing repository, fork with only the default branch.
         */
        default_branch_only?: boolean;
    } | null;
}
declare type CreateRepositoryForkResponseOKType = FullRepositoryAsResponse;
export interface CreateRepositoryForkResponseOK extends CreateRepositoryForkResponseOKType {
}
declare type CreateRepositoryForkResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface CreateRepositoryForkResponseError extends CreateRepositoryForkResponseErrorType {
}
export {};
//# sourceMappingURL=fork.d.ts.map