/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrivateUserAsResponse } from "../definitions/PrivateUserAsResponse";
import { PublicUserAsResponse } from "../definitions/PublicUserAsResponse";
import { BasicErrorAsResponse } from "../definitions/BasicErrorAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ValidationErrorAsResponse } from "../definitions/ValidationErrorAsResponse";
import { SimpleUserAsResponse } from "../definitions/SimpleUserAsResponse";
import { HovercardAsResponse } from "../definitions/HovercardAsResponse";
export interface GetAuthenticatedUserRequest extends HeadersOption, ErrorStrategyOption {
}
export declare type GetAuthenticatedUserResponseOK = PrivateUserAsResponse | PublicUserAsResponse;
declare type GetAuthenticatedUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse;
export interface GetAuthenticatedUserResponseError extends GetAuthenticatedUserResponseErrorType {
}
export interface UpdateAuthenticatedUserRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
         * The new name of the user.
         */
        name?: string;
        /**
         * The publicly visible email address of the user.
         */
        email?: string;
        /**
         * The new blog URL of the user.
         */
        blog?: string;
        /**
         * The new Twitter username of the user.
         */
        twitter_username?: string | null;
        /**
         * The new company of the user.
         */
        company?: string;
        /**
         * The new location of the user.
         */
        location?: string;
        /**
         * The new hiring availability of the user.
         */
        hireable?: boolean;
        /**
         * The new short biography of the user.
         */
        bio?: string;
    };
}
declare type UpdateAuthenticatedUserResponseOKType = PrivateUserAsResponse;
export interface UpdateAuthenticatedUserResponseOK extends UpdateAuthenticatedUserResponseOKType {
}
declare type UpdateAuthenticatedUserResponseErrorType = BasicErrorAsResponse & BasicErrorAsResponse & BasicErrorAsResponse & ValidationErrorAsResponse;
export interface UpdateAuthenticatedUserResponseError extends UpdateAuthenticatedUserResponseErrorType {
}
export interface GetUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A user ID. Only return users with an ID greater than this ID.
     */
    since?: number;
    /**
     * The number of results per page (max 100).
     */
    per_page?: number;
}
declare type GetUsersResponseOKType = Array<SimpleUserAsResponse>;
export interface GetUsersResponseOK extends GetUsersResponseOKType {
}
export declare type GetUsersResponseError = undefined;
export interface GetUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The handle for the GitHub user account.
     */
    username: string;
}
export declare type GetUserResponseOK = PrivateUserAsResponse | PublicUserAsResponse;
declare type GetUserResponseErrorType = BasicErrorAsResponse;
export interface GetUserResponseError extends GetUserResponseErrorType {
}
export interface GetUserContextRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The handle for the GitHub user account.
     */
    username: string;
    /**
     * Identifies which additional information you'd like to receive about the person's hovercard. Can be `organization`, `repository`, `issue`, `pull_request`. **Required** when using `subject_id`.
     */
    subject_type?: "organization" | "repository" | "issue" | "pull_request";
    /**
     * Uses the ID for the `subject_type` you specified. **Required** when using `subject_type`.
     */
    subject_id?: string;
}
declare type GetUserContextResponseOKType = HovercardAsResponse;
export interface GetUserContextResponseOK extends GetUserContextResponseOKType {
}
declare type GetUserContextResponseErrorType = BasicErrorAsResponse & ValidationErrorAsResponse;
export interface GetUserContextResponseError extends GetUserContextResponseErrorType {
}
export {};
//# sourceMappingURL=user.d.ts.map